@@ -9,7 +9,7 @@ use Exporter qw(import);
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2022-05-20'; # DATE
 our $DIST = 'Array-Sample-Partition'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 our @EXPORT_OK = qw(sample_partition);
 
@@ -43,7 +43,7 @@ Array::Sample::Partition - Sample elements from an array by equal partitions
 
 =head1 VERSION
 
-This document describes version 0.002 of Array::Sample::Partition (from Perl distribution Array-Sample-Partition), released on 2022-05-20.
+This document describes version 0.003 of Array::Sample::Partition (from Perl distribution Array-Sample-Partition), released on 2022-05-20.
 
 =head1 SYNOPSIS
 
@@ -94,7 +94,7 @@ Source repository is at L<https://github.com/perlancar/perl-Array-Sample-Partiti
 =head1 SEE ALSO
 
 Other sampling methods: L<Array::Sample::SysRand>,
-L<Array::Sample::SimpleRandom>.
+L<Array::Sample::SimpleRandom>, L<Array::Sample::WeightedRandom>.
 
 =head1 AUTHOR
 
